Microsoft Azure
===============

Coiled plans to support Azure in the latter half of 2023.

Until then, we'd like to direct you several open source solutions
for deploying Dask:

-  https://cloudprovider.dask.org/en/latest/azure.html
-  https://kubernetes.dask.org
-  https://gateway.dask.org

Additionally, if you want some of the Coiled features like longitudinal
analytics, idle shutdown, and user tracking, consider deploying
:doc:`Coiled Analytics <analytics>` on your open source Dask Clusters.
